==> flutter_ads-0.0.8.tar.gz: example/lib/home_page.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_ads/flutter_ads.dart';
class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {

  var test = "初始化激励视频广告";
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Container(
          child: Column(
            children: <Widget>[
              RaisedButton(
                onPressed: () {
                  Navigator.of(context).pushNamed("/splash");
                },
                child: Text("开屏广告"),
              ),
              RaisedButton(
                onPressed: () {
                  Navigator.of(context).pushNamed("/nativeads");
                },
                child: Text("普通广告"),
              ),
              RaisedButton(
                onPressed: () {
                  print("testReward");

                  if( Platform.isAndroid){
                    FlutterAds.initRewardVideo(appKey:"5007439",codeId: "907439399",userId:"1992",callback: (value){
                      print("广告结果$value");
                      test ="广告结果1$value";
                      setState(() {});
                    });
                  }else if(Platform.isIOS){
                    FlutterAds.initRewardVideo(appid: "5028237",placementID: "928237472",callback: (value){
                      print("广告结果$value");
                      test ="广告结果1$value";
                      setState(() {});
                    });
                  }



                },
                child: Text(test),
              ),
            ],
          ),
        ));
  }



}

==> flutter_ads-0.1.5.tar.gz: example/lib/home_page.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_ads/flutter_ads.dart';
import 'package:flutter_ads/ads_bannerview.dart';

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  var test = "加载激励视频广告";
  var test1 = "加载插屏视频广告";

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Container(
          child: Column(
            children: <Widget>[
              RaisedButton(
                onPressed: () {
                  Navigator.of(context).pushNamed("/splash");
                },
                child: Text("开屏广告"),
              ),
              RaisedButton(
                onPressed: () {
                  Navigator.of(context).pushNamed("/nativeads");
                },
                child: Text("普通广告"),
              ),
              RaisedButton(
                onPressed: () {
                  print("testReward");
                  FlutterAds.initRewardVideo(callback: (value) {
                    print("广告结果$value");
                    test = "广告结果1$value";
                    setState(() {});
                  });
                },
                child: Text(test),
              ),
              RaisedButton(
                onPressed: () {
                  print("testInsert");
                  FlutterAds.initInsertVideo(callback: (value) {
                    print("广告结果$value");
                    test1 = "广告结果1$value";
                    setState(() {});
                  });
                },
                child: Text(test1),
              ),
              Expanded(
                flex: 1,
                child: Container(),
              ),
              AdsBannerView(),
            ],
          ),
        ));
  }
}
